OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Unknown error" : "Άγνωστο σφάλμα",
    "File could not be found" : "Δεν μπορεί να βρεθεί το αρχείο",
    "Move or copy" : "Μετακίνηση ή αντιγραφή",
    "Download" : "Λήψη",
    "Delete" : "Διαγραφή",
    "Tags" : "Ετικέτες",
    "Show list view" : "Προβολή λίστας",
    "Show grid view" : "Προβολή πλέγματος",
    "Home" : "Αρχική",
    "Close" : "Κλείσιμο",
    "Favorites" : "Αγαπημένα",
    "Could not create folder \"{dir}\"" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\"",
    "This will stop your current uploads." : "Αυτό θα σταματήσει τις τρέχουσες μεταφορτώσεις.",
    "Upload cancelled." : "Η μεταφόρτωση ακυρώθηκε.",
    "Processing files …" : "Γίνεται επεξεργασία των αρχείων …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Αδυναμία φόρτωσης {filename} καθώς είναι κατάλογος ή έχει 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Δεν υπάρχει αρκετός ελεύθερος χώρος, μεταφορτώνεται {size1} αλλά υπάρχει χώρος μόνο για {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Ο φάκελος προορισμού \"{dir}\" δεν υπάρχει πλέον",
    "Not enough free space" : "Δεν επαρκεί ο ελεύθερος χώρος",
    "An unknown error has occurred" : "Προέκυψε άγνωστο σφάλμα.",
    "File could not be uploaded" : "Δεν ήταν δυνατή η μεταφόρτωση του αρχείου",
    "Uploading …" : "Μεταφόρτωση σε εξέλιξη ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} από {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Η μεταφόρτωση αυτού του αντικειμένου δεν υποστηρίζεται",
    "Target folder does not exist any more" : "Ο φάκελος προορισμού δεν υπάρχει πια",
    "Operation is blocked by access control" : "Η λειτουργία μπλοκάρεται από τον έλεγχο πρόσβασης",
    "Error when assembling chunks, status code {status}" : "Σφάλμα κατά την συλλογή τμημάτων, κωδικός κατάστασης {status}",
    "Actions" : "Ενέργειες",
    "Rename" : "Μετονομασία",
    "Move" : "Μετακίνηση",
    "Copy" : "Αντιγραφή",
    "Choose target folder" : "Επιλογή φακέλου προορισμού",
    "Edit locally" : "Επεξεργασία τοπικά",
    "Open" : "Άνοιγμα",
    "Delete file" : "Διαγραφή αρχείου",
    "Delete folder" : "Διαγραφή φακέλου",
    "Disconnect storage" : "Αποσύνδεση αποθηκευτικού χώρου",
    "Leave this share" : "Αποχωρήστε από αυτήν την κοινή χρήση",
    "Could not load info for file \"{file}\"" : "Αδυναμία φόρτωσης πληροφοριών για το αρχείο \"{file}\"",
    "Files" : "Αρχεία",
    "Details" : "Λεπτομέρειες",
    "Please select tag(s) to add to the selection" : "Επιλέξτε ετικέτα (ες) για προσθήκη στην επιλογή",
    "Apply tag(s) to selection" : "Εφαρμογή ετικετών στην επιλογή",
    "Select directory \"{dirName}\"" : "Επιλέξτε κατάλογο \"{dirName}\"",
    "Select file \"{fileName}\"" : "Επιλέξτε αρχείο \"{fileName}\"",
    "Pending" : "Εκκρεμεί",
    "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας",
    "This operation is forbidden" : "Αυτή η λειτουργία απαγορεύεται",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
    "copy" : "αντιγραφή",
    "Could not copy \"{file}\", target exists" : "Αδυναμία αντιγραφής του \"{file}\", υπάρχει ήδη.",
    "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
    "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
    "{newName} already exists" : "Το {newName} υπάρχει ήδη",
    "Could not rename \"{fileName}\", it does not exist any more" : "Αδυναμία μετονομασίας του \"{fileName}\", το αρχείο δεν υπάρχει πια.",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{targetName}\" χρησιμοποιείται ήδη στον φάκελο\"{dir}\". Παρακαλούμε διαλέξτε ένα διαφορετικό όνομα.",
    "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του αρχείου \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Αδυναμία δημιουργίας του αρχείου \"{file}\" επειδή υπάρχει ήδη",
    "Could not create folder \"{dir}\" because it already exists" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\" επειδή υπάρχει ήδη",
    "Could not fetch file details \"{file}\"" : "Δεν είναι δυνατή η ανάγνωση λεπτομερειών του αρχείου \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Σφάλμα διαγραφής του \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Κανένα αποτέλεσμα αναζήτησης σε άλλους φακέλους για {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Εισαγάγετε περισσότερους από δύο χαρακτήρες για αναζήτηση σε άλλους φακέλους",
    "Name" : "Όνομα",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε",
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
    "{dirs} and {files}" : "{dirs} και {files}",
    "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυφό","περιλαμβάνονται %n κρυφά"],
    "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
    "_Uploading %n file_::_Uploading %n files_" : ["Μεταφόρτωση %n αρχείου","Μεταφόρτωση %n αρχείων"],
    "New file/folder menu" : "Μενού νέου αρχείου/φακέλου",
    "Select file range" : "Επιλέξτε εύρος αρχείων",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "Χρήση {used} από {quota} ",
    "{used} used" : "Σε χρήση {used}",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "\"/\" is not allowed inside a file name." : "Το \"/\" δεν είναι επιτρεπτό εντός του ονόματος αρχείου.",
    "\"{name}\" is not an allowed filetype" : "Το \"{name}\" δεν είναι ένας επιτρεπτός τύπος αρχείου",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Ο αποθηκευτικός χώρος του/της {owner} είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ο φάκελος της ομάδας \"{mountPoint}\" είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ο εξωτερικός χώρος αποθήκευσης \"{mountPoint}\" είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός χώρος του {owner} είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ο φάκελος ομάδας \"{mountPoint}\" είναι σχεδόν πλήρης ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ο εξωτερικός χώρος αποθήκευσης \"{mountPoint}\" είναι σχεδόν πλήρης ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός σας χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Ταιριάζει \"{filter}\"","Ταιριάζουν \"{filter}\""],
    "View in folder" : "Προβολή στον φάκελο",
    "Copied!" : "Αντιγράφηκε!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
    "Path" : "Διαδρομή",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Αγαπημένα",
    "Favorite" : "Αγαπημένο",
    "You can only favorite a single file or folder at a time" : "Προσθήκη στα αγαπημένα ενός αρχείου ή φακέλου κάθε φορά",
    "New folder" : "Νέος φάκελος",
    "Upload file" : "Μεταφόρτωση αρχείου",
    "Recent" : "Πρόσφατα",
    "Not favorited" : "Δεν είναι αγαπημένο",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
    "Added to favorites" : "Προστέθηκε στα αγαπημένα",
    "Removed from favorites" : "Αφαιρέθηκε από τα αγαπημένα",
    "You added {file} to your favorites" : "Προσθέσατε το {file} στα αγαπημένα σας",
    "You removed {file} from your favorites" : "Αφαιρέσατε το {file} από τα αγαπημένα σας",
    "File changes" : "Αλλαγές αρχείου",
    "Created by {user}" : "Δημιουργήθηκε από τον {user}",
    "Changed by {user}" : "Άλλαξε από τον {user}",
    "Deleted by {user}" : "Διαγράφτηκε από τον {user}",
    "Restored by {user}" : "Επαναφέρθηκε από τον {user}",
    "Renamed by {user}" : "Μετονομάστηκε από τον {user}",
    "Moved by {user}" : "Μετακινήθηκε από τον {user}",
    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
    "You created {file}" : "Δημιουργήσατε το {file}",
    "You created an encrypted file in {file}" : "Δημιουργήσατε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{user} created {file}" : "Ο/η {user} δημιούργησε {file}",
    "{user} created an encrypted file in {file}" : "Ο/η {user} δημιούργησε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{file} was created in a public folder" : "Το {file} δημιουργήθηκε σε δημόσιο φάκελο",
    "You changed {file}" : "Αλλάξατε το {file}",
    "You changed an encrypted file in {file}" : "Αλλάξατε ένα κρυπτογραφημένο αρχείο {file}",
    "{user} changed {file}" : "Ο/η {user} άλλαξε το {file}",
    "{user} changed an encrypted file in {file}" : "Ο/η {user} άλλαξε κρυπτογραφημένο αρχείο {file}",
    "You deleted {file}" : "Διαγράψτε το {file}",
    "You deleted an encrypted file in {file}" : "Διαγράψατε ένα κρυπτογραφημένο αρχείο {file}",
    "{user} deleted {file}" : "Ο/η {user} διέγραψε το {file}",
    "{user} deleted an encrypted file in {file}" : "Ο/η {user} διέγραψε κρυπτογραφημένο αρχείο σε {file}",
    "You restored {file}" : "Επαναφέρατε το {file}",
    "{user} restored {file}" : "Ο/η {user} επανέφερε το {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Μετονομάσατε από {oldfile} (hidden) σε {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Μετονομάσατε το {oldfile} (hidden) σε {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Μετονομάσατε το {oldfile} (hidden) σε {newfile}",
    "You renamed {oldfile} to {newfile}" : "Μετονομάσατε το {oldfile} σε {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ο/Η {user} μετονομάστηκε σε {oldfile} (hidden) σε {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "Ο/Η {user} μετονόμασε σε {oldfile} (hidden) σε {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "Ο/Η {user} μετονόμασε σε {oldfile} σε {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "Ο/η {user} μετονόμασε το {oldfile} σε {newfile}",
    "You moved {oldfile} to {newfile}" : "Μεταφέρατε το {oldfile} σε {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Ο/η {user} μετέφερε το {oldfile} σε {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ένα αρχείο έχει προστεθεί ή αφαιρεθεί από τα <strong>αγαπημένα</strong> σας",
    "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Ένα αγαπημένο αρχείο ή φάκελός σας έχει <strong>τροποποιηθεί</strong>.",
    "All files" : "Όλα τα αρχεία",
    "Unlimited" : "Απεριόριστο",
    "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
    "Accept" : "Αποδοχή",
    "Reject" : "Απόρριψη",
    "Incoming ownership transfer from {user}" : "Εισερχόμενη μεταβίβαση κυριότητας από τον {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Δέχεστε την διαδρομή {path}?\n\nΣημείωση: Η διαδικασία μεταφοράς μπορεί να διαρκέσει πάνω από μία ώρα.",
    "Ownership transfer failed" : "Η μεταφορά κυριότητας απέτυχε",
    "Your ownership transfer of {path} to {user} failed." : "Η μεταφορά κυριότητας σας του {path} στον {user} απέτυχε.",
    "The ownership transfer of {path} from {user} failed." : "Η μεταφορά κυριότητας του {path} από {user} απέτυχε.",
    "Ownership transfer done" : "Η μεταφορά κυριότητας ολοκληρώθηκε",
    "Your ownership transfer of {path} to {user} has completed." : "Η μεταφορά κυριότητας σας του {path} στον {user} ολοκληρώθηκε.",
    "The ownership transfer of {path} from {user} has completed." : "Η μεταφορά κυριότητας του {path} στον {user} ολοκληρώθηκε.",
    "in %s" : "σε %s",
    "File Management" : "Διαχείριση αρχείων",
    "Transfer ownership of a file or folder" : "Μεταβίβαση κυριότητας αρχείου ή φακέλου",
    "Choose file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
    "Change" : "Αλλαγή",
    "New owner" : "Νέος κάτοχος",
    "Search users" : "Αναζήτηση χρηστών",
    "Choose a file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
    "Transfer" : "Μεταφορά",
    "Transfer {path} to {userid}" : "Μεταφορά {path} στον {userid}",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Ownership transfer request sent" : "Αποστολή αίτησης μεταβίβασης κυριότητας",
    "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δε σας ανήκει",
    "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
    "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
    "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
    "Cancel" : "Ακύρωση",
    "Create" : "Δημιουργία",
    "Create a new file with the selected template" : "Δημιουργήστε ένα νέο αρχείο με το επιλεγμένο πρότυπο",
    "Creating file" : "Δημιουργία αρχείου",
    "Blank" : "Κενό",
    "Unable to create new file from template" : "Δεν είναι δυνατή η δημιουργία νέου αρχείου από το πρότυπο",
    "Set up templates folder" : "Ρύθμιση φακέλου προτύπων",
    "Templates" : "Πρότυπα",
    "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
    "%s used" : "%s σε χρήση",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
    "Files settings" : "Ρυθμίσεις αρχείων",
    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
    "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
    "Toggle %1$s sublist" : "Εναλλαγή %1$s σε υπολίστα",
    "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Select all" : "Επιλογή όλων",
    "Upload too large" : "Πολύ μεγάλο αρχείο προς μεταφόρτωση",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να μεταφορτώσετε υπερβαίνουν το μέγιστο μέγεθος μεταφόρτωσης αρχείων σε αυτόν τον διακομιστή.",
    "No favorites yet" : "Κανένα αγαπημένο ακόμα",
    "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
    "Deleted files" : "Διαγραμμένα αρχεία",
    "Shares" : "Κοινόχρηστα",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Deleted shares" : "Διαγραμμένα κοινόχρηστα",
    "Pending shares" : "Κοινή χρήση σε εκκρεμότητα",
    "Text file" : "Αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο file.txt",
    "Select" : "Επιλογή",
    "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
    "New" : "Νέο",
    "Cannot transfer ownership of a file or folder you don't own" : "Δεν μπορεί να μεταβιβαστεί η κυριότητα αρχείου ή φακέλου που δεν σας ανήκει",
    "%s%% of %s used" : "%s%% από %s σε χρήση",
    "Settings" : "Ρυθμίσεις"
},
"nplurals=2; plural=(n != 1);");
